==> statehub-api-0.0.2.crate: statehub-api-0.0.2/src/v0/error.rs <==
//
// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
// Use is subject to license terms.
//

#![allow(clippy::use_self)]

use thiserror::Error;

use super::*;

mod impls;

#[derive(Debug, Error, Serialize, Deserialize)]
#[serde(rename_all = "camelCase")]
#[error("{msg}")]
pub struct Error {
    pub http_code: u16,
    pub http_status: String,
    pub error: StatehubError,
    pub msg: String,
}

#[derive(Clone, Debug, PartialEq, Hash, Serialize, Deserialize)]
#[serde(tag = "errorCode")]
pub enum StatehubError {
    InvalidToken,
    #[serde(rename_all = "camelCase")]
    ClusterNotAuthorized {
        permission: Permission,
        resource_name: String,
        resource_type: String,
    },
    ClusterNameConflict {
        cluster: ClusterName,
    },
    ClusterNotFound {
        cluster: ClusterName,
    },
    ClusterIsStateOwner {
        cluster: ClusterName,
        state: StateName,
    },
    StateNameConflict {
        state: StateName,
    },
    StateNotFound {
        state: StateName,
    },
    AwsLocationExists {
        state: StateName,
        region: AwsRegion,
    },
    AzureLocationExists {
        state: StateName,
        region: AzureRegion,
    },
    VolumeNotFound {
        state: StateName,
        volume: VolumeName,
    },
    UnknownError,
}

#[derive(Clone, Copy, Debug, PartialEq, Hash, SerializeDisplay, DeserializeFromStr)]
pub enum Permission {
    ReadClusters,
    CreateClusters,
    DeleteClusters,
    CreateClusterToken,
    ReadClusterToken,
    DeleteClusterToken,
    ReadClusterLocations,
    UpdateClusterLocations,
    ReadStates,
    CreateStates,
    DeleteStates,
    CreateStateOwner,
    DeleteStateOwner,
    CreateStateLocations,
    ReadStateLocations,
    DeleteStateLocations,
    ReadStateLocationPrincipals,
    CreateStateLocationPrincipals,
    UpdateStateLocationPle,
    ReadVolumes,
    CreateVolumes,
    DeleteVolumes,
    UpdateVolumeActiveLocation,
    DeleteVolumeActiveLocation,
    ReadOrganization,
    UpdateOrganization,
    ReadOrganizationRole,
    ReadPersonalTokens,
    CreatePersonalTokens,
    UpdatePersonalTokens,
    DeletePersonalTokens,
    ReadInvitations,
    CreateInvitations,
    UpdateInvitations,
    DeleteInvitations,
    ReadMembers,
    CreateMembers,
    UpdateMembers,
    DeleteMembers,
    ReadProfile,
    UpdateProfile,
}

==> statehub-api-0.0.12.crate: statehub-api-0.0.12/src/v0/error.rs <==
//
// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
// Use is subject to license terms.
//

#![allow(clippy::use_self)]

use thiserror::Error;

use super::*;

mod impls;

pub const UNAUTHENTICATED: &str = "UnauthenticatedError";
pub const VOLUME_NOT_FOUND: &str = "VolumeNotFoundError";
pub const CLUSTER_IS_STATE_OWNER: &str = "ClusterIsStateOwnerError";
pub const NOT_AUTHORIZED: &str = "NotAuthorizedError";
pub const CLUSTER_NOT_FOUND: &str = "ClusterNotFoundError";
pub const STATE_ALREADY_EXISTS: &str = "StateAlreadyExistsError";

#[derive(Debug, Error, Serialize, Deserialize)]
#[serde(rename_all = "camelCase")]
// #[error("{error_code}")]
pub struct Error {
    pub http_code: u16,
    pub http_status: String,
    pub error_code: String,
    pub msg: Option<String>,
    pub request_id: Option<String>,
}

#[derive(Clone, Copy, Debug, PartialEq, Hash, SerializeDisplay, DeserializeFromStr)]
pub enum Permission {
    ReadClusters,
    CreateClusters,
    DeleteClusters,
    CreateClusterToken,
    ReadClusterToken,
    DeleteClusterToken,
    ReadClusterLocations,
    UpdateClusterLocations,
    ReadStates,
    CreateStates,
    DeleteStates,
    CreateStateOwner,
    DeleteStateOwner,
    CreateStateLocations,
    ReadStateLocations,
    DeleteStateLocations,
    ReadStateLocationPrincipals,
    CreateStateLocationPrincipals,
    UpdateStateLocationPle,
    ReadVolumes,
    CreateVolumes,
    DeleteVolumes,
    UpdateVolumeActiveLocation,
    DeleteVolumeActiveLocation,
    ReadOrganization,
    UpdateOrganization,
    ReadOrganizationRole,
    ReadPersonalTokens,
    CreatePersonalTokens,
    UpdatePersonalTokens,
    DeletePersonalTokens,
    ReadInvitations,
    CreateInvitations,
    UpdateInvitations,
    DeleteInvitations,
    ReadMembers,
    CreateMembers,
    UpdateMembers,
    DeleteMembers,
    ReadProfile,
    UpdateProfile,
}
